==> v0.0.3.zip: shellfu/include/flow.sh <==
#!/bin/bash

ffoo import core


wait_until() {
    #
    # Wait until command succeeds (or fails)
    #
    # Repeat calling a command until it succeeds or returns
    # acceptable value.  For example:
    #
    #     wait_until -t 90 my_command
    #     wait_until -t 90 -d 30 my_expensive_command
    #     wait_until -r 7 command_that_should_return_7
    #     wait_until -R "-lt 7" command_that_should_return_less_than_7
    #     wait_until -e some_bash_builtin
    #
    local timeout=10
    local delay=1
    local use_eval=false
    local rv_test="-eq 0"
    while true; do case "$1" in
        -r) rv_test="-eq $2"; shift;    ;;
        -R) rv_test="$2"; shift;        ;;
        -e) use_eval=true; shift; break ;;
        -d) delay="$2"; shift 2;        ;;
        -t) timeout="$2"; shift 2;      ;;
        --) shift 1; break;             ;;
        *)  break;                      ;;
    esac done
    think "waiting for: $@"
    local elapsed=0
    local start=$(date +%s)
    while true;
    do
        sleep $delay
        local now=$(date +%s)
        local elapsed=$(($now - $start))
        local rv=0
        debug "\$@='$@'"
        if $use_eval;
        then
            eval $@;
            rv=$?
        else
            $@;
            rv=$?
        fi
        debug -v rv
        if [ $rv $rv_test ];
        then
            return 0;
        fi
        if test $elapsed -gt $timeout;
        then
            warn "timeout reached ($elapsed>$timeout) when waiting for ($rv $rv_test): $@"
            return 1
        fi
        think "waiting for another $delay s"
    done
}

==> v0.0.5.zip: shellfu/include/flow.sh <==
#!/bin/bash

ffoo import core


wait_until() {
    #
    # Wait until command succeeds (or fails)
    #
    # Repeat calling a command until it succeeds or exits with
    # acceptable status.  For example:
    #
    #     wait_until -t 90 my_command
    #     wait_until -t 90 -d 30 my_expensive_command
    #     wait_until -x 7 command_that_should_exit_with_7
    #     wait_until -X "-lt 7" command_that_should_exit_with_less_than_7
    #     wait_until -e some_bash_builtin
    #
    local timeout=10
    local delay=1
    local use_eval=false
    local es_test="-eq 0"
    while true; do case "$1" in
        -x) es_test="-eq $2"; shift;    ;;
        -X) es_test="$2"; shift;        ;;
        -e) use_eval=true; shift; break ;;
        -d) delay="$2"; shift 2;        ;;
        -t) timeout="$2"; shift 2;      ;;
        --) shift 1; break;             ;;
        *)  break;                      ;;
    esac done
    think "waiting for: $@"
    local elapsed=0
    local start=$(date +%s)
    while true;
    do
        sleep $delay
        local now=$(date +%s)
        local elapsed=$(($now - $start))
        local es=0
        debug "\$@='$@'"
        if $use_eval;
        then
            eval $@;
            es=$?
        else
            $@;
            es=$?
        fi
        debug -v es
        if [ $es $es_test ];
        then
            return 0;
        fi
        if test $elapsed -gt $timeout;
        then
            warn "timeout reached ($elapsed>$timeout) when waiting for ($es $es_test): $@"
            return 1
        fi
        think "waiting for another $delay s"
    done
}
